package com.vivek.marriage_center_collection;

import android.app.Activity;
import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

public class CenterCollectionDatabase extends Activity {
	
	public static final String KEY_ID = "id";
	public static final String KEY_ROUNDID = "round";
	public static final String KEY_PLAYERID = "playerid";
	public static final String KEY_MAAL = "maal";
	public static final String KEY_POINT = "point";
	public static final String KEY_WON = "won";
	private static final String DATABASE_NAME ="center_collection";
	private static final String DATABASE_TABLE= "collection";
	private static final int DATABASE_VERSION = 1;
	private DbHelper ourHelper;
	private final Context ourContext;
	private SQLiteDatabase ourDatabase;
	
	private static class DbHelper extends SQLiteOpenHelper{

		public DbHelper(Context context) {
			super(context, DATABASE_NAME, null, DATABASE_VERSION);
			// TODO Auto-generated constructor stub
		}

		@Override
		public void onCreate(SQLiteDatabase db) {
			// TODO Auto-generated method stub
			
			db.execSQL("CREATE TABLE " + DATABASE_TABLE +" ("+
					KEY_ID + " INTEGER PRIMARY KEY AUTOINCREMENT, "+
					KEY_ROUNDID + " INTEGER, "+
					KEY_PLAYERID + " INTEGER, "+
					KEY_POINT + " INTEGER, "+
					KEY_MAAL + " INTEGER, "+
					KEY_WON+ " INTEGER );"			
				);
		}

		@Override
		public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {			
			db.execSQL("DROP TABLE IF EXISTS " + DATABASE_TABLE);
			onCreate(db);
		}
		
	}
	
	public CenterCollectionDatabase(Context c)
	{
		ourContext = c;
	}
	
	public CenterCollectionDatabase open() throws SQLException{
		ourHelper = new DbHelper(ourContext);
		ourDatabase = ourHelper.getWritableDatabase();
		return this;
		
	}
	public void close()
	{
		ourHelper.close();
	}

	/************************Putting data to database**************************************************/
	public long add_score(int round, int playerid, int point, int maal, int won) {  
		
		ContentValues cv = new ContentValues();
		cv.put(KEY_ROUNDID, round);
		cv.put(KEY_PLAYERID, playerid);
		cv.put(KEY_POINT, point);
		cv.put(KEY_MAAL, maal);
		cv.put(KEY_WON, won);
		
		return ourDatabase.insert(DATABASE_TABLE, null, cv);
	}
	
	/***********************Checking if there exist some data in database******************************/
	public int ifdata_in_table() 
	{
		Cursor c = ourDatabase.rawQuery("select count('"+KEY_ROUNDID+"') as number from '"+DATABASE_TABLE+"'", null);
		c.moveToFirst();
		
		int num_index = c.getColumnIndex("number");
			
		int number = c.getInt(num_index);
		Log.i("totalrecord", Integer.toString(num_index));
		
		c.close();
		
		return number;
	}
	
	/***********************Checking who is the winner of round****************************************/
	public int check_winner(int r)
	{

		Cursor c = ourDatabase.rawQuery("select playerid from collection where round="+r+" and won='1'" , null);
		c.moveToFirst();
				
		int winnerId = c.getInt(0);	
		c.close();
	
		return winnerId;
	}
	
	/***********************getting total maal of the round  (Mt) *************************************/
	
	public int get_total_maal(int r)
	{
		Cursor c = ourDatabase.rawQuery("select maal from collection where round= "+r+"", null);
		
		int totalmaal=0;
		for(c.moveToFirst(); !c.isAfterLast(); c.moveToNext())
		{
			totalmaal = totalmaal+c.getInt(0);
			
		}
		
		c.close();
		return totalmaal;
	}
	
	/***********************getting point of specific player on specific round (Pp)*******************/
			
	public int point_of_player(int r, int pid)
	{
		Cursor c = ourDatabase.rawQuery("select point from collection where round= "+r+" and playerid= "+pid+"", null);
				
		c.moveToFirst();
		int playerpoint = c.getInt(0);
		
		c.close();
		
		return playerpoint;
	}
	
	/***********************getting maal of specific player on specific round (Mp)*********************/
	public int maal_of_player(int r, int pid)
	{
		Cursor c = ourDatabase.rawQuery("select maal from collection where round= "+r+" and playerid= "+pid+"", null);
		c.moveToFirst();
		
		int playermaal = c.getInt(0);
		c.close();
		
		return playermaal;
	}
	
	/**********************Getting the list of winners in each round***********************************/
	public int[] getting_all_winner()
	{
		
		Cursor c = ourDatabase.rawQuery("select playerid from collection where won='1'", null);
		c.moveToFirst();
		
		int number_of_row = c.getCount();
		
		int[] winnerlist = new int[number_of_row];
		int i=0;
		for(c.moveToFirst(); !c.isAfterLast(); c.moveToNext())
		{
			winnerlist[i] = c.getInt(0);
			Log.i("winner of "+i, String.valueOf(winnerlist[i]));
			i++;
		}
		
		c.close();
		
		return winnerlist;
	}
	
	
	
	/***********************Deleting all the records from database**************************************/
	public void delete_database()
	{
		if(ifdata_in_table()> 0)
		{
			ourDatabase.delete(DATABASE_TABLE, null, null);
			Log.i("Data Deleted", "Data Successfully Deleted");
		}
		
		
	}
}
